#[repr(u32)]pub enum LedType {
NumLock = 1,
CapsLock = 2,
ScrollLock = 3,
Compose = 4,
Kana = 5,
UnknownOrdinal_(u32),
}Expand description
An LedType represents an LED on a device that can be turned on or off. When applicable, the definition of each LED is derived from one of the following sources albeit with a Fuchsia-specific numeric value:
- USB HID usage codes for usage page 0x0008 (LED)
Variants