#[repr(u32)]pub enum UnitType {
Show 14 variants
None = 0,
Other = 1,
Meters = 2,
Grams = 3,
Degrees = 4,
EnglishAngularVelocity = 5,
SiLinearVelocity = 6,
SiLinearAcceleration = 7,
Webers = 8,
Candelas = 9,
Pascals = 10,
Lux = 11,
Seconds = 12,
UnknownOrdinal_(u32),
}Expand description
This provides an easy, standardized way to specify units. New units can be added as needed. Each UnitType should be named after a specific unit that should be fully distinguished by the name (E.g: Use METERS instead of DISTANCE). More complicated units that need to be differentiated should begin with SI_ (for Internation System of Units) or ENGLISH_ (for English System of Units).
Variants
None = 0
Other = 1
Meters = 2
Grams = 3
Degrees = 4
EnglishAngularVelocity = 5
SiLinearVelocity = 6
SiLinearAcceleration = 7
Webers = 8
Candelas = 9
Pascals = 10
Lux = 11
Seconds = 12
UnknownOrdinal_(u32)