pub struct InputDeviceGetDescriptorResponse {
pub descriptor: DeviceDescriptor,
}Fields
descriptor: DeviceDescriptorTrait Implementations
Sourceimpl Clone for InputDeviceGetDescriptorResponse
impl Clone for InputDeviceGetDescriptorResponse
Sourcefn clone(&self) -> InputDeviceGetDescriptorResponse
fn clone(&self) -> InputDeviceGetDescriptorResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for &'a InputDeviceGetDescriptorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for &'a InputDeviceGetDescriptorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for InputDeviceGetDescriptorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for InputDeviceGetDescriptorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InputDeviceGetDescriptorResponse<'static>>, ___E> for &'a InputDeviceGetDescriptorResponsewhere
___E: Encoder + ?Sized,
&'a InputDeviceGetDescriptorResponse: Encode<InputDeviceGetDescriptorResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, InputDeviceGetDescriptorResponse<'static>>, ___E> for &'a InputDeviceGetDescriptorResponsewhere
___E: Encoder + ?Sized,
&'a InputDeviceGetDescriptorResponse: Encode<InputDeviceGetDescriptorResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a InputDeviceGetDescriptorResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputDeviceGetDescriptorResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a InputDeviceGetDescriptorResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputDeviceGetDescriptorResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, InputDeviceGetDescriptorResponse<'static>>, ___E> for InputDeviceGetDescriptorResponsewhere
___E: Encoder + ?Sized,
InputDeviceGetDescriptorResponse: Encode<InputDeviceGetDescriptorResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, InputDeviceGetDescriptorResponse<'static>>, ___E> for InputDeviceGetDescriptorResponsewhere
___E: Encoder + ?Sized,
InputDeviceGetDescriptorResponse: Encode<InputDeviceGetDescriptorResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<InputDeviceGetDescriptorResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputDeviceGetDescriptorResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<InputDeviceGetDescriptorResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputDeviceGetDescriptorResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<InputDeviceGetDescriptorResponse<'de>> for InputDeviceGetDescriptorResponse
impl<'de> FromWire<InputDeviceGetDescriptorResponse<'de>> for InputDeviceGetDescriptorResponse
Sourcefn from_wire(
wire: InputDeviceGetDescriptorResponse<'de>,
) -> InputDeviceGetDescriptorResponse
fn from_wire( wire: InputDeviceGetDescriptorResponse<'de>, ) -> InputDeviceGetDescriptorResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<InputDeviceGetDescriptorResponse<'de>> for InputDeviceGetDescriptorResponse
impl<'de> FromWireRef<InputDeviceGetDescriptorResponse<'de>> for InputDeviceGetDescriptorResponse
Sourcefn from_wire_ref(
wire: &InputDeviceGetDescriptorResponse<'de>,
) -> InputDeviceGetDescriptorResponse
fn from_wire_ref( wire: &InputDeviceGetDescriptorResponse<'de>, ) -> InputDeviceGetDescriptorResponse
Converts the given reference to this type.
Sourceimpl Ord for InputDeviceGetDescriptorResponse
impl Ord for InputDeviceGetDescriptorResponse
Sourcefn cmp(&self, other: &InputDeviceGetDescriptorResponse) -> Ordering
fn cmp(&self, other: &InputDeviceGetDescriptorResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InputDeviceGetDescriptorResponse
impl PartialEq for InputDeviceGetDescriptorResponse
Sourcefn eq(&self, other: &InputDeviceGetDescriptorResponse) -> bool
fn eq(&self, other: &InputDeviceGetDescriptorResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for InputDeviceGetDescriptorResponse
impl PartialOrd for InputDeviceGetDescriptorResponse
impl Eq for InputDeviceGetDescriptorResponse
impl StructuralPartialEq for InputDeviceGetDescriptorResponse