pub struct InputDeviceGetInputReportResponse {
pub report: InputReport,
}Fields
report: InputReportTrait Implementations
Sourceimpl<___E> Encode<InputDeviceGetInputReportResponse<'static>, ___E> for InputDeviceGetInputReportResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<InputDeviceGetInputReportResponse<'static>, ___E> for InputDeviceGetInputReportResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetInputReportResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetInputReportResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, InputDeviceGetInputReportResponse<'static>>, ___E> for InputDeviceGetInputReportResponsewhere
___E: Encoder + ?Sized,
InputDeviceGetInputReportResponse: Encode<InputDeviceGetInputReportResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, InputDeviceGetInputReportResponse<'static>>, ___E> for InputDeviceGetInputReportResponsewhere
___E: Encoder + ?Sized,
InputDeviceGetInputReportResponse: Encode<InputDeviceGetInputReportResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputDeviceGetInputReportResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputDeviceGetInputReportResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<InputDeviceGetInputReportResponse<'de>> for InputDeviceGetInputReportResponse
impl<'de> FromWire<InputDeviceGetInputReportResponse<'de>> for InputDeviceGetInputReportResponse
Sourcefn from_wire(wire: InputDeviceGetInputReportResponse<'de>) -> Self
fn from_wire(wire: InputDeviceGetInputReportResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for InputDeviceGetInputReportResponse
impl PartialEq for InputDeviceGetInputReportResponse
Sourcefn eq(&self, other: &InputDeviceGetInputReportResponse) -> bool
fn eq(&self, other: &InputDeviceGetInputReportResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InputDeviceGetInputReportResponse