pub struct InputReport {
pub event_time: Option<i64>,
pub mouse: Option<MouseInputReport>,
pub sensor: Option<SensorInputReport>,
pub touch: Option<TouchInputReport>,
pub keyboard: Option<KeyboardInputReport>,
pub consumer_control: Option<ConsumerControlInputReport>,
pub trace_id: Option<u64>,
pub report_id: Option<u8>,
pub wake_lease: Option<EventPair>,
}Expand description
An InputReport is a single report that is created by an input device.
An InputReport can contain one of many different report types. The report
types are not mutually exclusive. The event_time is the time in
nanoseconds when the report was generated.
Fields
event_time: Option<i64>mouse: Option<MouseInputReport>sensor: Option<SensorInputReport>touch: Option<TouchInputReport>keyboard: Option<KeyboardInputReport>consumer_control: Option<ConsumerControlInputReport>trace_id: Option<u64>report_id: Option<u8>wake_lease: Option<EventPair>Trait Implementations
Sourceimpl Debug for InputReport
impl Debug for InputReport
Sourceimpl Default for InputReport
impl Default for InputReport
Sourcefn default() -> InputReport
fn default() -> InputReport
Returns the “default value” for a type. Read more
Sourceimpl<___E> Encode<InputReport<'static>, ___E> for InputReportwhere
___E: Encoder + ?Sized + HandleEncoder,
impl<___E> Encode<InputReport<'static>, ___E> for InputReportwhere
___E: Encoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<InputReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<InputReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<InputReport<'de>> for InputReport
impl<'de> FromWire<InputReport<'de>> for InputReport
Sourcefn from_wire(wire_: InputReport<'de>) -> Self
fn from_wire(wire_: InputReport<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for InputReport
impl PartialEq for InputReport
impl StructuralPartialEq for InputReport