pub struct OutputReport {
pub keyboard: Option<KeyboardOutputReport>,
}Expand description
A single report containing output information for an input device. Output information typically represents device output to the user (E.g: LEDs, tactile feedback, etc).
Fields
keyboard: Option<KeyboardOutputReport>Trait Implementations
Sourceimpl Clone for OutputReport
impl Clone for OutputReport
Sourcefn clone(&self) -> OutputReport
fn clone(&self) -> OutputReport
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputReport
impl Debug for OutputReport
Sourceimpl Default for OutputReport
impl Default for OutputReport
Sourcefn default() -> OutputReport
fn default() -> OutputReport
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<OutputReport<'static>, ___E> for &'a OutputReportwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<OutputReport<'static>, ___E> for &'a OutputReportwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<OutputReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<OutputReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OutputReport<'static>, ___E> for OutputReportwhere
___E: Encoder + ?Sized,
impl<___E> Encode<OutputReport<'static>, ___E> for OutputReportwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<OutputReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<OutputReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<OutputReport<'de>> for OutputReport
impl<'de> FromWire<OutputReport<'de>> for OutputReport
Sourcefn from_wire(wire_: OutputReport<'de>) -> OutputReport
fn from_wire(wire_: OutputReport<'de>) -> OutputReport
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<OutputReport<'de>> for OutputReport
impl<'de> FromWireRef<OutputReport<'de>> for OutputReport
Sourcefn from_wire_ref(wire: &OutputReport<'de>) -> OutputReport
fn from_wire_ref(wire: &OutputReport<'de>) -> OutputReport
Converts the given reference to this type.
Sourceimpl Hash for OutputReport
impl Hash for OutputReport
Sourceimpl Ord for OutputReport
impl Ord for OutputReport
Sourcefn cmp(&self, other: &OutputReport) -> Ordering
fn cmp(&self, other: &OutputReport) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OutputReport
impl PartialEq for OutputReport
Sourceimpl PartialOrd for OutputReport
impl PartialOrd for OutputReport
impl Eq for OutputReport
impl StructuralPartialEq for OutputReport