pub struct DeviceInformation {
pub vendor_id: Option<u32>,
pub product_id: Option<u32>,
pub version: Option<u32>,
pub polling_rate: Option<i64>,
}Expand description
DeviceInformation provides more information about the device and lets a client distinguish between devices (e.g between two touchscreens that come from different vendors). If the device is a HID device, then the id information will come from the device itself. Other, non-HID devices may assign the ids in the driver, so it will be the driver author’s responsibility to assign sensible ids.
Fields
vendor_id: Option<u32>product_id: Option<u32>version: Option<u32>polling_rate: Option<i64>Trait Implementations
Sourceimpl Clone for DeviceInformation
impl Clone for DeviceInformation
Sourcefn clone(&self) -> DeviceInformation
fn clone(&self) -> DeviceInformation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceInformation
impl Debug for DeviceInformation
Sourceimpl Default for DeviceInformation
impl Default for DeviceInformation
Sourcefn default() -> DeviceInformation
fn default() -> DeviceInformation
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<DeviceInformation<'static>, ___E> for &'a DeviceInformationwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<DeviceInformation<'static>, ___E> for &'a DeviceInformationwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<DeviceInformation<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<DeviceInformation<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceInformation<'static>, ___E> for DeviceInformationwhere
___E: Encoder + ?Sized,
impl<___E> Encode<DeviceInformation<'static>, ___E> for DeviceInformationwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<DeviceInformation<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<DeviceInformation<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<DeviceInformation<'de>> for DeviceInformation
impl<'de> FromWire<DeviceInformation<'de>> for DeviceInformation
Sourcefn from_wire(wire_: DeviceInformation<'de>) -> DeviceInformation
fn from_wire(wire_: DeviceInformation<'de>) -> DeviceInformation
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceInformation<'de>> for DeviceInformation
impl<'de> FromWireRef<DeviceInformation<'de>> for DeviceInformation
Sourcefn from_wire_ref(wire: &DeviceInformation<'de>) -> DeviceInformation
fn from_wire_ref(wire: &DeviceInformation<'de>) -> DeviceInformation
Converts the given reference to this type.
Sourceimpl Hash for DeviceInformation
impl Hash for DeviceInformation
Sourceimpl Ord for DeviceInformation
impl Ord for DeviceInformation
Sourcefn cmp(&self, other: &DeviceInformation) -> Ordering
fn cmp(&self, other: &DeviceInformation) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceInformation
impl PartialEq for DeviceInformation
Sourceimpl PartialOrd for DeviceInformation
impl PartialOrd for DeviceInformation
impl Copy for DeviceInformation
impl Eq for DeviceInformation
impl StructuralPartialEq for DeviceInformation