pub struct FeatureReport {
pub sensor: Option<SensorFeatureReport>,
pub touch: Option<TouchFeatureReport>,
}Expand description
A single report containing the feature information for an input device. Feature reports obtained from the device show the current state of the device. Sending a feature report to the device sets the device in that state.
Fields
sensor: Option<SensorFeatureReport>touch: Option<TouchFeatureReport>Trait Implementations
Sourceimpl Clone for FeatureReport
impl Clone for FeatureReport
Sourcefn clone(&self) -> FeatureReport
fn clone(&self) -> FeatureReport
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeatureReport
impl Debug for FeatureReport
Sourceimpl Default for FeatureReport
impl Default for FeatureReport
Sourcefn default() -> FeatureReport
fn default() -> FeatureReport
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<FeatureReport<'static>, ___E> for &'a FeatureReportwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<FeatureReport<'static>, ___E> for &'a FeatureReportwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<FeatureReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<FeatureReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FeatureReport<'static>, ___E> for FeatureReportwhere
___E: Encoder + ?Sized,
impl<___E> Encode<FeatureReport<'static>, ___E> for FeatureReportwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<FeatureReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<FeatureReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<FeatureReport<'de>> for FeatureReport
impl<'de> FromWire<FeatureReport<'de>> for FeatureReport
Sourcefn from_wire(wire_: FeatureReport<'de>) -> FeatureReport
fn from_wire(wire_: FeatureReport<'de>) -> FeatureReport
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<FeatureReport<'de>> for FeatureReport
impl<'de> FromWireRef<FeatureReport<'de>> for FeatureReport
Sourcefn from_wire_ref(wire: &FeatureReport<'de>) -> FeatureReport
fn from_wire_ref(wire: &FeatureReport<'de>) -> FeatureReport
Converts the given reference to this type.
Sourceimpl Hash for FeatureReport
impl Hash for FeatureReport
Sourceimpl Ord for FeatureReport
impl Ord for FeatureReport
Sourcefn cmp(&self, other: &FeatureReport) -> Ordering
fn cmp(&self, other: &FeatureReport) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FeatureReport
impl PartialEq for FeatureReport
Sourceimpl PartialOrd for FeatureReport
impl PartialOrd for FeatureReport
impl Eq for FeatureReport
impl StructuralPartialEq for FeatureReport