pub struct OutputDescriptor {
pub keyboard: Option<KeyboardOutputDescriptor>,
}Expand description
Describes the output reports that a physical input device will accept. Output information typically represents device output to the user (E.g: LEDs, tactile feedback, etc).
Fields
keyboard: Option<KeyboardOutputDescriptor>Trait Implementations
Sourceimpl Clone for OutputDescriptor
impl Clone for OutputDescriptor
Sourcefn clone(&self) -> OutputDescriptor
fn clone(&self) -> OutputDescriptor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputDescriptor
impl Debug for OutputDescriptor
Sourceimpl Default for OutputDescriptor
impl Default for OutputDescriptor
Sourcefn default() -> OutputDescriptor
fn default() -> OutputDescriptor
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<OutputDescriptor<'static>, ___E> for &'a OutputDescriptorwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<OutputDescriptor<'static>, ___E> for &'a OutputDescriptorwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<OutputDescriptor<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<OutputDescriptor<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OutputDescriptor<'static>, ___E> for OutputDescriptorwhere
___E: Encoder + ?Sized,
impl<___E> Encode<OutputDescriptor<'static>, ___E> for OutputDescriptorwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<OutputDescriptor<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<OutputDescriptor<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<OutputDescriptor<'de>> for OutputDescriptor
impl<'de> FromWire<OutputDescriptor<'de>> for OutputDescriptor
Sourcefn from_wire(wire_: OutputDescriptor<'de>) -> OutputDescriptor
fn from_wire(wire_: OutputDescriptor<'de>) -> OutputDescriptor
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<OutputDescriptor<'de>> for OutputDescriptor
impl<'de> FromWireRef<OutputDescriptor<'de>> for OutputDescriptor
Sourcefn from_wire_ref(wire: &OutputDescriptor<'de>) -> OutputDescriptor
fn from_wire_ref(wire: &OutputDescriptor<'de>) -> OutputDescriptor
Converts the given reference to this type.
Sourceimpl Hash for OutputDescriptor
impl Hash for OutputDescriptor
Sourceimpl Ord for OutputDescriptor
impl Ord for OutputDescriptor
Sourcefn cmp(&self, other: &OutputDescriptor) -> Ordering
fn cmp(&self, other: &OutputDescriptor) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OutputDescriptor
impl PartialEq for OutputDescriptor
Sourceimpl PartialOrd for OutputDescriptor
impl PartialOrd for OutputDescriptor
impl Eq for OutputDescriptor
impl StructuralPartialEq for OutputDescriptor