pub struct SelectiveReportingFeatureReport {
pub surface_switch: Option<bool>,
pub button_switch: Option<bool>,
}Expand description
Selective Reporting Feature Report indicating which types of input are reported.
Fields
surface_switch: Option<bool>Trait Implementations
Sourceimpl Clone for SelectiveReportingFeatureReport
impl Clone for SelectiveReportingFeatureReport
Sourcefn clone(&self) -> SelectiveReportingFeatureReport
fn clone(&self) -> SelectiveReportingFeatureReport
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SelectiveReportingFeatureReport
impl Default for SelectiveReportingFeatureReport
Sourcefn default() -> SelectiveReportingFeatureReport
fn default() -> SelectiveReportingFeatureReport
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<SelectiveReportingFeatureReport<'static>, ___E> for &'a SelectiveReportingFeatureReportwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<SelectiveReportingFeatureReport<'static>, ___E> for &'a SelectiveReportingFeatureReportwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SelectiveReportingFeatureReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SelectiveReportingFeatureReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SelectiveReportingFeatureReport<'static>, ___E> for SelectiveReportingFeatureReportwhere
___E: Encoder + ?Sized,
impl<___E> Encode<SelectiveReportingFeatureReport<'static>, ___E> for SelectiveReportingFeatureReportwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SelectiveReportingFeatureReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SelectiveReportingFeatureReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<SelectiveReportingFeatureReport<'de>> for SelectiveReportingFeatureReport
impl<'de> FromWire<SelectiveReportingFeatureReport<'de>> for SelectiveReportingFeatureReport
Sourcefn from_wire(
wire_: SelectiveReportingFeatureReport<'de>,
) -> SelectiveReportingFeatureReport
fn from_wire( wire_: SelectiveReportingFeatureReport<'de>, ) -> SelectiveReportingFeatureReport
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<SelectiveReportingFeatureReport<'de>> for SelectiveReportingFeatureReport
impl<'de> FromWireRef<SelectiveReportingFeatureReport<'de>> for SelectiveReportingFeatureReport
Sourcefn from_wire_ref(
wire: &SelectiveReportingFeatureReport<'de>,
) -> SelectiveReportingFeatureReport
fn from_wire_ref( wire: &SelectiveReportingFeatureReport<'de>, ) -> SelectiveReportingFeatureReport
Converts the given reference to this type.
Sourceimpl Ord for SelectiveReportingFeatureReport
impl Ord for SelectiveReportingFeatureReport
Sourcefn cmp(&self, other: &SelectiveReportingFeatureReport) -> Ordering
fn cmp(&self, other: &SelectiveReportingFeatureReport) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SelectiveReportingFeatureReport
impl PartialEq for SelectiveReportingFeatureReport
Sourcefn eq(&self, other: &SelectiveReportingFeatureReport) -> bool
fn eq(&self, other: &SelectiveReportingFeatureReport) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SelectiveReportingFeatureReport
impl PartialOrd for SelectiveReportingFeatureReport
impl Copy for SelectiveReportingFeatureReport
impl Eq for SelectiveReportingFeatureReport
impl StructuralPartialEq for SelectiveReportingFeatureReport