pub struct SensorAxis {
pub axis: Axis,
pub type_: SensorType,
}Expand description
A SensorAxis is a normal Axis with an additional SensorType to describe what the
axis is measuring.
Fields
axis: Axistype_: SensorTypeTrait Implementations
Sourceimpl Clone for SensorAxis
impl Clone for SensorAxis
Sourcefn clone(&self) -> SensorAxis
fn clone(&self) -> SensorAxis
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SensorAxis
impl Debug for SensorAxis
Sourceimpl<'a, ___E> Encode<SensorAxis, ___E> for &'a SensorAxiswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SensorAxis, ___E> for &'a SensorAxiswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SensorAxis>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SensorAxis>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SensorAxis, ___E> for SensorAxiswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SensorAxis, ___E> for SensorAxiswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SensorAxis>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SensorAxis>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SensorAxis>, ___E> for &'a SensorAxis
impl<'a, ___E> EncodeOption<Box<'static, SensorAxis>, ___E> for &'a SensorAxis
Sourcefn encode_option(
this: Option<&'a SensorAxis>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SensorAxis>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SensorAxis>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SensorAxis>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SensorAxis>, ___E> for SensorAxis
impl<___E> EncodeOption<Box<'static, SensorAxis>, ___E> for SensorAxis
Sourcefn encode_option(
this: Option<SensorAxis>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SensorAxis>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SensorAxis>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SensorAxis>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SensorAxis> for SensorAxis
impl FromWire<SensorAxis> for SensorAxis
Sourcefn from_wire(wire: SensorAxis) -> SensorAxis
fn from_wire(wire: SensorAxis) -> SensorAxis
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SensorAxis> for SensorAxis
impl FromWireRef<SensorAxis> for SensorAxis
Sourcefn from_wire_ref(wire: &SensorAxis) -> SensorAxis
fn from_wire_ref(wire: &SensorAxis) -> SensorAxis
Converts the given reference to this type.
Sourceimpl Hash for SensorAxis
impl Hash for SensorAxis
Sourceimpl Ord for SensorAxis
impl Ord for SensorAxis
Sourcefn cmp(&self, other: &SensorAxis) -> Ordering
fn cmp(&self, other: &SensorAxis) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SensorAxis
impl PartialEq for SensorAxis
Sourceimpl PartialOrd for SensorAxis
impl PartialOrd for SensorAxis
impl Copy for SensorAxis
impl Eq for SensorAxis
impl StructuralPartialEq for SensorAxis