SensorFeatureDescriptor

Struct SensorFeatureDescriptor 

pub struct SensorFeatureDescriptor {
    pub report_interval: Option<Axis>,
    pub sensitivity: Option<Vec<SensorAxis>>,
    pub supports_reporting_state: Option<bool>,
    pub threshold_high: Option<Vec<SensorAxis>>,
    pub threshold_low: Option<Vec<SensorAxis>>,
    pub sampling_rate: Option<Axis>,
    pub report_id: Option<u8>,
}
Describes the format of the sensor’s feature report. Feature reports can be requested from the sensor, or sent to the sensor.

At least one of the fields below must be present.

Fields

report_interval: Option<Axis>sensitivity: Option<Vec<SensorAxis>>supports_reporting_state: Option<bool>threshold_high: Option<Vec<SensorAxis>>threshold_low: Option<Vec<SensorAxis>>sampling_rate: Option<Axis>report_id: Option<u8>