pub struct SensorFeatureReport {
pub report_interval: Option<i64>,
pub sensitivity: Option<Vec<i64>>,
pub reporting_state: Option<SensorReportingState>,
pub threshold_high: Option<Vec<i64>>,
pub threshold_low: Option<Vec<i64>>,
pub sampling_rate: Option<i64>,
}Expand description
A SensorFeatureReport describes the features of a given sensor. If a FeatureReport is sent to the Input Device it sets the configuration of the device. If a FeatureReport is requested from the Input Device it shows the device’s current configuration.
Fields
report_interval: Option<i64>sensitivity: Option<Vec<i64>>reporting_state: Option<SensorReportingState>threshold_high: Option<Vec<i64>>threshold_low: Option<Vec<i64>>sampling_rate: Option<i64>Trait Implementations
Sourceimpl Clone for SensorFeatureReport
impl Clone for SensorFeatureReport
Sourcefn clone(&self) -> SensorFeatureReport
fn clone(&self) -> SensorFeatureReport
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SensorFeatureReport
impl Debug for SensorFeatureReport
Sourceimpl Default for SensorFeatureReport
impl Default for SensorFeatureReport
Sourcefn default() -> SensorFeatureReport
fn default() -> SensorFeatureReport
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<SensorFeatureReport<'static>, ___E> for &'a SensorFeatureReportwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<SensorFeatureReport<'static>, ___E> for &'a SensorFeatureReportwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SensorFeatureReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SensorFeatureReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SensorFeatureReport<'static>, ___E> for SensorFeatureReportwhere
___E: Encoder + ?Sized,
impl<___E> Encode<SensorFeatureReport<'static>, ___E> for SensorFeatureReportwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SensorFeatureReport<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SensorFeatureReport<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<SensorFeatureReport<'de>> for SensorFeatureReport
impl<'de> FromWire<SensorFeatureReport<'de>> for SensorFeatureReport
Sourcefn from_wire(wire_: SensorFeatureReport<'de>) -> SensorFeatureReport
fn from_wire(wire_: SensorFeatureReport<'de>) -> SensorFeatureReport
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<SensorFeatureReport<'de>> for SensorFeatureReport
impl<'de> FromWireRef<SensorFeatureReport<'de>> for SensorFeatureReport
Sourcefn from_wire_ref(wire: &SensorFeatureReport<'de>) -> SensorFeatureReport
fn from_wire_ref(wire: &SensorFeatureReport<'de>) -> SensorFeatureReport
Converts the given reference to this type.
Sourceimpl Hash for SensorFeatureReport
impl Hash for SensorFeatureReport
Sourceimpl Ord for SensorFeatureReport
impl Ord for SensorFeatureReport
Sourcefn cmp(&self, other: &SensorFeatureReport) -> Ordering
fn cmp(&self, other: &SensorFeatureReport) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SensorFeatureReport
impl PartialEq for SensorFeatureReport
Sourceimpl PartialOrd for SensorFeatureReport
impl PartialOrd for SensorFeatureReport
impl Eq for SensorFeatureReport
impl StructuralPartialEq for SensorFeatureReport