pub struct SensorInputDescriptor {
pub values: Option<Vec<SensorAxis>>,
pub report_id: Option<u8>,
}Expand description
Describes the format of the input report that will be sent from the sensor to the device.
Fields
values: Option<Vec<SensorAxis>>report_id: Option<u8>Trait Implementations
Sourceimpl Clone for SensorInputDescriptor
impl Clone for SensorInputDescriptor
Sourcefn clone(&self) -> SensorInputDescriptor
fn clone(&self) -> SensorInputDescriptor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SensorInputDescriptor
impl Debug for SensorInputDescriptor
Sourceimpl Default for SensorInputDescriptor
impl Default for SensorInputDescriptor
Sourcefn default() -> SensorInputDescriptor
fn default() -> SensorInputDescriptor
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<SensorInputDescriptor<'static>, ___E> for &'a SensorInputDescriptorwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<SensorInputDescriptor<'static>, ___E> for &'a SensorInputDescriptorwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SensorInputDescriptor<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SensorInputDescriptor<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SensorInputDescriptor<'static>, ___E> for SensorInputDescriptorwhere
___E: Encoder + ?Sized,
impl<___E> Encode<SensorInputDescriptor<'static>, ___E> for SensorInputDescriptorwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SensorInputDescriptor<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SensorInputDescriptor<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<SensorInputDescriptor<'de>> for SensorInputDescriptor
impl<'de> FromWire<SensorInputDescriptor<'de>> for SensorInputDescriptor
Sourcefn from_wire(wire_: SensorInputDescriptor<'de>) -> SensorInputDescriptor
fn from_wire(wire_: SensorInputDescriptor<'de>) -> SensorInputDescriptor
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<SensorInputDescriptor<'de>> for SensorInputDescriptor
impl<'de> FromWireRef<SensorInputDescriptor<'de>> for SensorInputDescriptor
Sourcefn from_wire_ref(wire: &SensorInputDescriptor<'de>) -> SensorInputDescriptor
fn from_wire_ref(wire: &SensorInputDescriptor<'de>) -> SensorInputDescriptor
Converts the given reference to this type.
Sourceimpl Hash for SensorInputDescriptor
impl Hash for SensorInputDescriptor
Sourceimpl Ord for SensorInputDescriptor
impl Ord for SensorInputDescriptor
Sourcefn cmp(&self, other: &SensorInputDescriptor) -> Ordering
fn cmp(&self, other: &SensorInputDescriptor) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SensorInputDescriptor
impl PartialEq for SensorInputDescriptor
Sourceimpl PartialOrd for SensorInputDescriptor
impl PartialOrd for SensorInputDescriptor
impl Eq for SensorInputDescriptor
impl StructuralPartialEq for SensorInputDescriptor