InputReportsReaderLocalServerHandler

Trait InputReportsReaderLocalServerHandler 

pub trait InputReportsReaderLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn read_input_reports(
        &mut self,
        responder: Responder<ReadInputReports, ___T>,
    ) -> impl Future<Output = ()>;
}
A server handler for the InputReportsReader protocol.

See InputReportsReader for more details.

Required Methods

fn read_input_reports( &mut self, responder: Responder<ReadInputReports, ___T>, ) -> impl Future<Output = ()>

This is a Hanging-Get function to read the reports in the InputReport FIFO. This will not reply until there is at least one report available. If there is already one outstanding Hanging-Get, calling this again will return ZX_ERR_ALREADY_BOUND.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> InputReportsReaderLocalServerHandler<___T> for Local<___H>
where ___H: InputReportsReaderServerHandler<___T>, ___T: Transport,

Source

async fn read_input_reports( &mut self, responder: Responder<ReadInputReports, ___T>, )

Implementors