InputReportsReaderV2LocalClientHandler

Trait InputReportsReaderV2LocalClientHandler 

pub trait InputReportsReaderV2LocalClientHandler<___T: Transport = Channel> {
    // Required method
    fn on_input_reports(
        &mut self,
        request: Request<OnInputReports, ___T>,
    ) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A client handler for the InputReportsReaderV2 protocol.

See InputReportsReaderV2 for more details.

Required Methods

fn on_input_reports( &mut self, request: Request<OnInputReports, ___T>, ) -> impl Future<Output = ()>

The device pushes events to the client. The client does not need to acknowledge every report; it can allow multiple reports to be in flight up to max_unacknowledged_reports.

Streaming begins automatically on connection.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<___H, ___T> InputReportsReaderV2LocalClientHandler<___T> for Local<___H>
where ___H: InputReportsReaderV2ClientHandler<___T>, ___T: Transport,

Source

async fn on_input_reports(&mut self, request: Request<OnInputReports, ___T>)

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors