#[repr(C)]pub struct InputDeviceGetDescriptorResponse<'de> {
pub descriptor: DeviceDescriptor<'de>,
}Expand description
The wire type corresponding to InputDeviceGetDescriptorResponse.
Fields
descriptor: DeviceDescriptor<'de>Trait Implementations
Sourceimpl Constrained for InputDeviceGetDescriptorResponse<'_>
impl Constrained for InputDeviceGetDescriptorResponse<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, InputDeviceGetDescriptorResponse<'_>>,
_: <InputDeviceGetDescriptorResponse<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, InputDeviceGetDescriptorResponse<'_>>, _: <InputDeviceGetDescriptorResponse<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for InputDeviceGetDescriptorResponse<'de>
impl<'de> Debug for InputDeviceGetDescriptorResponse<'de>
Sourceimpl<'de, ___D> Decode<___D> for InputDeviceGetDescriptorResponse<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for InputDeviceGetDescriptorResponse<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for &'a InputDeviceGetDescriptorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for &'a InputDeviceGetDescriptorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for InputDeviceGetDescriptorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for InputDeviceGetDescriptorResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for InputDeviceGetDescriptorResponse<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<DeviceDescriptor<'static>, ___E>,
impl<___E, T0> Encode<InputDeviceGetDescriptorResponse<'static>, ___E> for InputDeviceGetDescriptorResponse<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<DeviceDescriptor<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<InputDeviceGetDescriptorResponse<'de>> for InputDeviceGetDescriptorResponse
impl<'de> FromWire<InputDeviceGetDescriptorResponse<'de>> for InputDeviceGetDescriptorResponse
Sourcefn from_wire(
wire: InputDeviceGetDescriptorResponse<'de>,
) -> InputDeviceGetDescriptorResponse
fn from_wire( wire: InputDeviceGetDescriptorResponse<'de>, ) -> InputDeviceGetDescriptorResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<InputDeviceGetDescriptorResponse<'de>> for InputDeviceGetDescriptorResponse
impl<'de> FromWireRef<InputDeviceGetDescriptorResponse<'de>> for InputDeviceGetDescriptorResponse
Sourcefn from_wire_ref(
wire: &InputDeviceGetDescriptorResponse<'de>,
) -> InputDeviceGetDescriptorResponse
fn from_wire_ref( wire: &InputDeviceGetDescriptorResponse<'de>, ) -> InputDeviceGetDescriptorResponse
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for InputDeviceGetDescriptorResponse<'de>
impl<'de> IntoNatural for InputDeviceGetDescriptorResponse<'de>
Sourcetype Natural = InputDeviceGetDescriptorResponse
type Natural = InputDeviceGetDescriptorResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for InputDeviceGetDescriptorResponse<'static>
impl Wire for InputDeviceGetDescriptorResponse<'static>
Sourcetype Narrowed<'de> = InputDeviceGetDescriptorResponse<'de>
type Narrowed<'de> = InputDeviceGetDescriptorResponse<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(
out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>,
)
fn zero_padding( out_: &mut MaybeUninit<InputDeviceGetDescriptorResponse<'static>>, )
Writes zeroes to the padding for this type, if any.