#[repr(C)]pub struct InputDeviceGetInputReportRequest {
pub device_type: DeviceType,
}Expand description
The wire type corresponding to InputDeviceGetInputReportRequest.
Fields
device_type: DeviceTypeTrait Implementations
Sourceimpl Clone for InputDeviceGetInputReportRequest
impl Clone for InputDeviceGetInputReportRequest
Sourcefn clone(&self) -> InputDeviceGetInputReportRequest
fn clone(&self) -> InputDeviceGetInputReportRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for InputDeviceGetInputReportRequest
impl Constrained for InputDeviceGetInputReportRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, InputDeviceGetInputReportRequest>,
_: <InputDeviceGetInputReportRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, InputDeviceGetInputReportRequest>, _: <InputDeviceGetInputReportRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for InputDeviceGetInputReportRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for InputDeviceGetInputReportRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<InputDeviceGetInputReportRequest, ___E> for &'a InputDeviceGetInputReportRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InputDeviceGetInputReportRequest, ___E> for &'a InputDeviceGetInputReportRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetInputReportRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetInputReportRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InputDeviceGetInputReportRequest, ___E> for InputDeviceGetInputReportRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InputDeviceGetInputReportRequest, ___E> for InputDeviceGetInputReportRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InputDeviceGetInputReportRequest, InputDeviceGetInputReportRequest>
const COPY_OPTIMIZATION: CopyOptimization<InputDeviceGetInputReportRequest, InputDeviceGetInputReportRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetInputReportRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetInputReportRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<InputDeviceGetInputReportRequest, ___E> for InputDeviceGetInputReportRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<DeviceType, ___E>,
impl<___E, T0> Encode<InputDeviceGetInputReportRequest, ___E> for InputDeviceGetInputReportRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<DeviceType, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetInputReportRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetInputReportRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<InputDeviceGetInputReportRequest> for InputDeviceGetInputReportRequest
impl FromWire<InputDeviceGetInputReportRequest> for InputDeviceGetInputReportRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InputDeviceGetInputReportRequest, InputDeviceGetInputReportRequest>
const COPY_OPTIMIZATION: CopyOptimization<InputDeviceGetInputReportRequest, InputDeviceGetInputReportRequest>
Sourcefn from_wire(
wire: InputDeviceGetInputReportRequest,
) -> InputDeviceGetInputReportRequest
fn from_wire( wire: InputDeviceGetInputReportRequest, ) -> InputDeviceGetInputReportRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<InputDeviceGetInputReportRequest> for InputDeviceGetInputReportRequest
impl FromWireRef<InputDeviceGetInputReportRequest> for InputDeviceGetInputReportRequest
Sourcefn from_wire_ref(
wire: &InputDeviceGetInputReportRequest,
) -> InputDeviceGetInputReportRequest
fn from_wire_ref( wire: &InputDeviceGetInputReportRequest, ) -> InputDeviceGetInputReportRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for InputDeviceGetInputReportRequest
impl IntoNatural for InputDeviceGetInputReportRequest
Sourcetype Natural = InputDeviceGetInputReportRequest
type Natural = InputDeviceGetInputReportRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for InputDeviceGetInputReportRequest
impl Wire for InputDeviceGetInputReportRequest
Sourcetype Narrowed<'de> = InputDeviceGetInputReportRequest
type Narrowed<'de> = InputDeviceGetInputReportRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<InputDeviceGetInputReportRequest>)
fn zero_padding(out_: &mut MaybeUninit<InputDeviceGetInputReportRequest>)
Writes zeroes to the padding for this type, if any.