#[repr(C)]pub struct SensorAxis {
pub axis: Axis,
pub type_: SensorType,
}Expand description
The wire type corresponding to SensorAxis.
Fields
axis: Axistype_: SensorTypeTrait Implementations
Sourceimpl Clone for SensorAxis
impl Clone for SensorAxis
Sourcefn clone(&self) -> SensorAxis
fn clone(&self) -> SensorAxis
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SensorAxis
impl Constrained for SensorAxis
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, SensorAxis>,
_: <SensorAxis as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, SensorAxis>, _: <SensorAxis as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for SensorAxis
impl Debug for SensorAxis
Sourceimpl<___D> Decode<___D> for SensorAxiswhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SensorAxiswhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SensorAxis, ___E> for &'a SensorAxiswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SensorAxis, ___E> for &'a SensorAxiswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SensorAxis>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SensorAxis>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SensorAxis, ___E> for SensorAxiswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SensorAxis, ___E> for SensorAxiswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SensorAxis>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SensorAxis>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<SensorAxis, ___E> for SensorAxis<T0, T1>
impl<___E, T0, T1> Encode<SensorAxis, ___E> for SensorAxis<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SensorAxis>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SensorAxis>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SensorAxis> for SensorAxis
impl FromWire<SensorAxis> for SensorAxis
Sourcefn from_wire(wire: SensorAxis) -> SensorAxis
fn from_wire(wire: SensorAxis) -> SensorAxis
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SensorAxis> for SensorAxis
impl FromWireRef<SensorAxis> for SensorAxis
Sourcefn from_wire_ref(wire: &SensorAxis) -> SensorAxis
fn from_wire_ref(wire: &SensorAxis) -> SensorAxis
Converts the given reference to this type.
Sourceimpl IntoNatural for SensorAxis
impl IntoNatural for SensorAxis
Sourcetype Natural = SensorAxis
type Natural = SensorAxis
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SensorAxis
impl Wire for SensorAxis
Sourcetype Narrowed<'de> = SensorAxis
type Narrowed<'de> = SensorAxis
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<SensorAxis>)
fn zero_padding(out_: &mut MaybeUninit<SensorAxis>)
Writes zeroes to the padding for this type, if any.