pub trait InputReportsReaderServerHandler<___T: Transport = Channel> {
// Required method
fn read_input_reports(
&mut self,
responder: Responder<ReadInputReports, ___T>,
) -> impl Future<Output = ()> + Send;
}Expand description
A server handler for the InputReportsReader protocol.
See InputReportsReader for more details.
Required Methods
Sourcefn read_input_reports(
&mut self,
responder: Responder<ReadInputReports, ___T>,
) -> impl Future<Output = ()> + Send
fn read_input_reports( &mut self, responder: Responder<ReadInputReports, ___T>, ) -> impl Future<Output = ()> + Send
This is a Hanging-Get function to read the reports in the InputReport FIFO. This will not reply until there is at least one report available. If there is already one outstanding Hanging-Get, calling this again will return ZX_ERR_ALREADY_BOUND.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.